@@ -14,11 +14,6 @@ def configuration(parent_package='', top_path=None):
     config.add_subpackage("flash")
     config.add_subpackage("nyx")
     config.add_subpackage("orion")
-    config.add_subpackage("ramses")
-    config.add_subpackage("tiger")
-    config.add_subpackage("art")
-    config.add_subpackage("maestro")
-    config.add_subpackage("castro")
     config.add_subpackage("stream")
     config.add_subpackage("pluto")
     config.add_subpackage("flash/tests")
