@@ -1,27 +1,17 @@
 """
 Testsuite for PlotWindow class
 
-Author: Nathan Goldbaum <goldbaum@ucolick.org>
-Affiliation: UCSC Astronomy
-Homepage: http://yt-project.org/
-License:
-  Copyright (C) 2012 Nathan Goldbaum.  All Rights Reserved.
 
-  This file is part of yt.
 
-  yt is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 3 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
+
+#-----------------------------------------------------------------------------
+# Copyright (c) 2013, yt Development Team.
+#
+# Distributed under the terms of the Modified BSD License.
+#
+# The full license is in the file COPYING.txt, distributed with this software.
+#-----------------------------------------------------------------------------
 import itertools
 import os
 import tempfile
@@ -104,8 +94,10 @@ def test_attributes():
     for ax in 'xyz':
         for attr_name in ATTR_ARGS.keys():
             for args in ATTR_ARGS[attr_name]:
-                yield PlotWindowAttributeTest(pf, plot_field, ax, attr_name,
-                                              args, decimals)
+                test = PlotWindowAttributeTest(pf, plot_field, ax, attr_name,
+                                               args, decimals)
+                test_attributes.__name__ = test.description
+                yield test
 
 
 @requires_pf(WT)
