@@ -1,28 +1,18 @@
 """
 Import the components of the volume rendering extension
 
-Author: Matthew Turk <matthewturk@gmail.com>
-Affiliation: KIPAC/SLAC/Stanford
-Homepage: http://yt-project.org/
-License:
-  Copyright (C) 2009 Matthew Turk.  All Rights Reserved.
 
-  This file is part of yt.
 
-  yt is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 3 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License
-  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+#-----------------------------------------------------------------------------
+# Copyright (c) 2013, yt Development Team.
+#
+# Distributed under the terms of the Modified BSD License.
+#
+# The full license is in the file COPYING.txt, distributed with this software.
+#-----------------------------------------------------------------------------
+
 import __builtin__
 import numpy as np
 
@@ -82,6 +72,9 @@ class Camera(ParallelAnalysisInterface):
         cubical, but if not, it is left/right, top/bottom, front/back.
     resolution : int or list of ints
         The number of pixels in each direction.
+    transfer_function : `yt.visualization.volume_rendering.TransferFunction`
+        The transfer function used to map values to colors in an image.  If
+        not specified, defaults to a ProjectionTransferFunction.
     north_vector : array_like, optional
         The 'up' direction for the plane of rays.  If not specific, calculated
         automatically.
@@ -194,7 +187,7 @@ class Camera(ParallelAnalysisInterface):
     _tf_figure = None
     _render_figure = None
     def __init__(self, center, normal_vector, width,
-                 resolution, transfer_function,
+                 resolution, transfer_function = None,
                  north_vector = None, steady_north=False,
                  volume = None, fields = None,
                  log_fields = None,
@@ -668,13 +661,14 @@ class Camera(ParallelAnalysisInterface):
             del nz
         else:
             nim = im
-        ax = self._pylab.imshow(nim[:,:,:3]/nim[:,:,:3].max(), origin='lower')
+        ax = self._pylab.imshow(nim[:,:,:3]/nim[:,:,:3].max(), origin='upper')
         return ax
 
     def draw(self):
         self._pylab.draw()
     
     def save_annotated(self, fn, image, enhance=True, dpi=100):
+        image = image.swapaxes(0,1) 
         ax = self.show_mpl(image, enhance=enhance)
         self.annotate(ax.axes, enhance)
         self._pylab.savefig(fn, bbox_inches='tight', facecolor='black', dpi=dpi)
@@ -1168,6 +1162,10 @@ class HEALpixCamera(Camera):
                  sub_samples = 5, log_fields = None, volume = None,
                  pf = None, use_kd=True, no_ghost=False, use_light=False,
                  inner_radius = 10):
+        print "Because of recent relicensing, we currently cannot provide"
+        print "HEALpix functionality.  Please visit yt-users for more"
+        print "information."
+        raise NotImplementedError
         ParallelAnalysisInterface.__init__(self)
         if pf is not None: self.pf = pf
         self.center = np.array(center, dtype='float64')
@@ -1311,6 +1309,7 @@ class AdaptiveHEALpixCamera(Camera):
                  sub_samples = 5, log_fields = None, volume = None,
                  pf = None, use_kd=True, no_ghost=False,
                  rays_per_cell = 0.1, max_nside = 8192):
+        raise NotImplementedError
         ParallelAnalysisInterface.__init__(self)
         if pf is not None: self.pf = pf
         self.center = np.array(center, dtype='float64')
@@ -1470,7 +1469,7 @@ class FisheyeCamera(Camera):
 
 class MosaicCamera(Camera):
     def __init__(self, center, normal_vector, width,
-                 resolution, transfer_function,
+                 resolution, transfer_function = None,
                  north_vector = None, steady_north=False,
                  volume = None, fields = None,
                  log_fields = None,
@@ -2058,6 +2057,10 @@ def allsky_projection(pf, center, radius, nside, field, weight = None,
     """
     # We manually modify the ProjectionTransferFunction to get it to work the
     # way we want, with a second field that's also passed through.
+    print "Because of recent relicensing, we currently cannot provide"
+    print "HEALpix functionality.  Please visit yt-users for more"
+    print "information."
+    raise NotImplementedError
     fields = [field]
     center = np.array(center, dtype='float64')
     if weight is not None:
@@ -2122,6 +2125,10 @@ def allsky_projection(pf, center, radius, nside, field, weight = None,
 
 def plot_allsky_healpix(image, nside, fn, label = "", rotation = None,
                         take_log = True, resolution=512, cmin=None, cmax=None):
+    print "Because of recent relicensing, we currently cannot provide"
+    print "HEALpix functionality.  Please visit yt-users for more"
+    print "information."
+    raise NotImplementedError
     import matplotlib.figure
     import matplotlib.backends.backend_agg
     if rotation is None: rotation = np.eye(3).astype("float64")
@@ -2175,6 +2182,7 @@ class ProjectionCamera(Camera):
                 log_fields=self.log_fields, 
                 le=le, re=re, north_vector=north_vector,
                 no_ghost=no_ghost)
+        self.center = center
 
     def get_sampler(self, args):
         if self.interpolated:
